@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2015-04-11'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-07-04'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -146,8 +146,10 @@ sub gen_help {
 
         # find all the categories
         my %options_by_cat; # val=[options...]
-        for (keys %$opts) {
-            push @{ $options_by_cat{$opts->{$_}{category}} }, $_;
+        for my $optkey (keys %$opts) {
+            for my $cat (@{ $opts->{$optkey}{categories} }) {
+                push @{ $options_by_cat{$cat} }, $optkey;
+            }
         }
 
         my $cats_spec = $clidocdata->{option_categories};
@@ -233,7 +235,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.06 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-04-11.
+This document describes version 0.07 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-07-04.
 
 =head1 DESCRIPTION
 
